==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_hu_HU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Kattintson az eszköz más alkalmazásokból való eléréséhez.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>Kattintson a lemez kiadásához.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="185"/>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz-kezelő</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="280"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz csatlakoztatva.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="299"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz eltávolítva.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="342"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz csatolva ide: %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="356"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz leválasztva
Most már eltávolíthatja az USB háttértárat vagy CD/DVD lemezt.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="388"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>Nem lehet csatolni az eszközt: %1&lt;br&gt; %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="394"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>A(z) „%1” eszköz csatolva ide: %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="424"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>Nem lehet leválasztani az eszközt: %1&lt;br&gt; %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="428"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>A(z) „%1” eszköz leválasztva</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="444"/>
        <source>No devices Available.</source>
        <translation>Nem érhetők el eszközök.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>A Razor cserélhetőeszköz-kezelő beállításai</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Működés</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Ha az eszköz csatlakoztatva van</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>Felugró menü</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Show info</source>
        <translation>Információ megjelenítése</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Do nothing</source>
        <translation>Ne tegyen semmit</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_hu_HU.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Kattintson az eszköz más alkalmazásokból való eléréséhez.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Kattintson a lemez kiadásához.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Cserélhetőeszköz-kezelő</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz csatlakoztatva.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>A(z) &lt;b&gt;&lt;nobr&gt;„%1”&lt;/nobr&gt;&lt;/b&gt; eszköz eltávolítva.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>A Razor cserélhetőeszköz-kezelő beállításai</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Működés</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Ha az eszköz csatlakoztatva van</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Felugró menü</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Információ megjelenítése</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Ne tegyen semmit</translation>
    </message>
</context>
</TS>
